@@ -5,11 +5,14 @@
   has <- paste(names(which(support)), collapse = ", ")
   not <- paste(names(which(!support)), collapse = ", ")
 
-  packageStartupMessage(sprintf("Linkging to ImageMagick %s\nEnabled features: %s\nDisabled features: %s",
+  packageStartupMessage(sprintf("Linking to ImageMagick %s\nEnabled features: %s\nDisabled features: %s",
                                 as.character(magick_config()$version), has, not))
   if(magick_config()$version >= 7)
     packageStartupMessage(c("Attention: the 'magick' package has been compiled with ImageMagick-7 which is known to have problems.\n",
 "Rebuilding against ImageMagick-6 is recommended."))
+
+  # For RStudio
+  autoviewer_enable()
 }
 
 .onLoad <- function(lib, pkg){
